Scrapbag
========

Install Dependencies
----------------------

.. code-block:: console

    $ pip install -r requirements.txt

Generate docs
-------------
Documentation powered by sphinx.

.. code-block:: console

    $ cd docs && make docs OUTPUT_FORMAT
